@@ -1,9 +1,9 @@
 from unit.models.applicationForm import ApplicationFormDTO
 from unit.models.application import IndividualApplicationDTO, BusinessApplicationDTO, ApplicationDocumentDTO
-from unit.models.account import DepositAccountDTO, AccountLimitsDTO, AccountDepositProductDTO
+from unit.models.account import DepositAccountDTO, AccountLimitsDTO, AccountDepositProductDTO, CreditAccountDTO
 from unit.models.customer import IndividualCustomerDTO, BusinessCustomerDTO
 from unit.models.card import IndividualDebitCardDTO, BusinessDebitCardDTO, IndividualVirtualDebitCardDTO,\
-    BusinessVirtualDebitCardDTO, PinStatusDTO, CardLimitsDTO
+    BusinessVirtualDebitCardDTO, PinStatusDTO, CardLimitsDTO, BusinessCreditCardDTO, BusinessVirtualCreditCardDTO
 from unit.models.transaction import *
 from unit.models.payment import AchPaymentDTO, BookPaymentDTO, WirePaymentDTO, AchReceivedPaymentDTO
 from unit.models.payment import AchPaymentDTO, BookPaymentDTO, WirePaymentDTO, BillPaymentDTO
@@ -42,6 +42,9 @@ mappings = {
         "depositAccount": lambda _id, _type, attributes, relationships:
         DepositAccountDTO.from_json_api(_id, _type, attributes, relationships),
 
+        "creditAccount": lambda _id, _type, attributes, relationships:
+        CreditAccountDTO.from_json_api(_id, _type, attributes, relationships),
+
         "limits": lambda _id, _type, attributes, relationships:
         decode_limits(attributes),
 
@@ -51,12 +54,18 @@ mappings = {
         "businessDebitCard": lambda _id, _type, attributes, relationships:
         BusinessDebitCardDTO.from_json_api(_id, _type, attributes, relationships),
 
+        "businessCreditCard": lambda _id, _type, attributes, relationships:
+        BusinessCreditCardDTO.from_json_api(_id, _type, attributes, relationships),
+
         "individualVirtualDebitCard": lambda _id, _type, attributes, relationships:
         IndividualVirtualDebitCardDTO.from_json_api(_id, _type, attributes, relationships),
 
         "businessVirtualDebitCard": lambda _id, _type, attributes, relationships:
         BusinessVirtualDebitCardDTO.from_json_api(_id, _type, attributes, relationships),
 
+        "businessVirtualCreditCard": lambda _id, _type, attributes, relationships:
+        BusinessVirtualCreditCardDTO.from_json_api(_id, _type, attributes, relationships),
+
         "originatedAchTransaction": lambda _id, _type, attributes, relationships:
         OriginatedAchTransactionDTO.from_json_api(_id, _type, attributes, relationships),
 
@@ -109,7 +118,7 @@ mappings = {
         ReturnedCheckDepositTransactionDTO.from_json_api(_id, _type, attributes, relationships),
 
         "paymentAdvanceTransaction": lambda _id, _type, attributes, relationships:
-        PaymentAdvanceTransactionTransactionDTO.from_json_api(_id, _type, attributes, relationships),
+        PaymentAdvanceTransactionDTO.from_json_api(_id, _type, attributes, relationships),
 
         "repaidPaymentAdvanceTransaction": lambda _id, _type, attributes, relationships:
         RepaidPaymentAdvanceTransactionDTO.from_json_api(_id, _type, attributes, relationships),
